@@ -1,7 +1,7 @@
-# Create two example functions
-ae_summary <- function(...) {
+ae_summary <<- function(...) {
   paste("results of", deparse(match.call(), nlines = 1))
 }
-ae_specific <- function(...) {
+
+ae_specific <<- function(...) {
   paste("results of", deparse(match.call(), nlines = 1))
 }
